require 'racc/parser'


require "rd/parser-util"
require "forwardable"
require "strscan"

module RD

class RDInlineParser < ::Racc::Parser

module_eval <<'..end rd/rdinlineparser.ry modeval..ide4f41be34b', 'rd/rdinlineparser.ry', 292
include ParserUtility
extend Forwardable

EM_OPEN = '((*'
EM_OPEN_RE = /\A#{Regexp.quote(EM_OPEN)}/
EM_CLOSE = '*))'
EM_CLOSE_RE = /\A#{Regexp.quote(EM_CLOSE)}/
CODE_OPEN = '(({'
CODE_OPEN_RE = /\A#{Regexp.quote(CODE_OPEN)}/
CODE_CLOSE = '}))'
CODE_CLOSE_RE = /\A#{Regexp.quote(CODE_CLOSE)}/
VAR_OPEN = '((|'
VAR_OPEN_RE = /\A#{Regexp.quote(VAR_OPEN)}/
VAR_CLOSE = '|))'
VAR_CLOSE_RE = /\A#{Regexp.quote(VAR_CLOSE)}/
KBD_OPEN = '((%'
KBD_OPEN_RE = /\A#{Regexp.quote(KBD_OPEN)}/
KBD_CLOSE = '%))'
KBD_CLOSE_RE = /\A#{Regexp.quote(KBD_CLOSE)}/
INDEX_OPEN = '((:'
INDEX_OPEN_RE = /\A#{Regexp.quote(INDEX_OPEN)}/
INDEX_CLOSE = ':))'
INDEX_CLOSE_RE = /\A#{Regexp.quote(INDEX_CLOSE)}/
REF_OPEN = '((<'
REF_OPEN_RE = /\A#{Regexp.quote(REF_OPEN)}/
REF_CLOSE = '>))'
REF_CLOSE_RE = /\A#{Regexp.quote(REF_CLOSE)}/
FOOTNOTE_OPEN = '((-'
FOOTNOTE_OPEN_RE = /\A#{Regexp.quote(FOOTNOTE_OPEN)}/
FOOTNOTE_CLOSE = '-))'
FOOTNOTE_CLOSE_RE = /\A#{Regexp.quote(FOOTNOTE_CLOSE)}/
VERB_OPEN = "(('"
VERB_OPEN_RE = /\A#{Regexp.quote(VERB_OPEN)}/
VERB_CLOSE = "'))"
VERB_CLOSE_RE = /\A#{Regexp.quote(VERB_CLOSE)}/

BAR = "|"
BAR_RE = /\A#{Regexp.quote(BAR)}/
QUOTE = '"'
QUOTE_RE = /\A#{Regexp.quote(QUOTE)}/
SLASH = "/"
SLASH_RE = /\A#{Regexp.quote(SLASH)}/
BACK_SLASH = "\\"
BACK_SLASH_RE = /\A#{Regexp.quote(BACK_SLASH)}/
URL = "URL:"
URL_RE = /\A#{Regexp.quote(URL)}/

# Workaround for Regexp option change of Ruby 1.5.x
other_re_mode = Regexp::EXTENDED
if RUBY_VERSION > "1.5"
  other_re_mode |= Regexp::MULTILINE
else
  other_re_mode |= Regexp::POSIXLINE
end

OTHER_RE = Regexp.new(
		  "\\A.+?(?=#{Regexp.quote(EM_OPEN)}|#{Regexp.quote(EM_CLOSE)}|
                  #{Regexp.quote(CODE_OPEN)}|#{Regexp.quote(CODE_CLOSE)}|
                  #{Regexp.quote(VAR_OPEN)}|#{Regexp.quote(VAR_CLOSE)}|
                  #{Regexp.quote(KBD_OPEN)}|#{Regexp.quote(KBD_CLOSE)}|
                  #{Regexp.quote(INDEX_OPEN)}|#{Regexp.quote(INDEX_CLOSE)}|
                  #{Regexp.quote(REF_OPEN)}|#{Regexp.quote(REF_CLOSE)}|
                #{Regexp.quote(FOOTNOTE_OPEN)}|#{Regexp.quote(FOOTNOTE_CLOSE)}|
                  #{Regexp.quote(VERB_OPEN)}|#{Regexp.quote(VERB_CLOSE)}|
                  #{Regexp.quote(BAR)}|
                  #{Regexp.quote(QUOTE)}|
                  #{Regexp.quote(SLASH)}|
                  #{Regexp.quote(BACK_SLASH)}|
                  #{Regexp.quote(URL)})", other_re_mode)

def initialize(bp)
  @blockp = bp
end

def_delegator(:@blockp, :tree)

def parse(src)
  @src = StringScanner.new(src)
  @pre = ""
  @yydebug = true
  do_parse
end

def next_token
  return [false, false] if @src.empty?
#  p @src.rest if @yydebug
  if ret = @src.scan(EM_OPEN_RE)
    @pre << ret
    [:EM_OPEN, ret]
  elsif ret = @src.scan(EM_CLOSE_RE)
    @pre << ret
    [:EM_CLOSE, ret]
  elsif ret = @src.scan(CODE_OPEN_RE)
    @pre << ret
    [:CODE_OPEN, ret]
  elsif ret = @src.scan(CODE_CLOSE_RE)
    @pre << ret
    [:CODE_CLOSE, ret]
  elsif ret = @src.scan(VAR_OPEN_RE)
    @pre << ret
    [:VAR_OPEN, ret]
  elsif ret = @src.scan(VAR_CLOSE_RE)
    @pre << ret
    [:VAR_CLOSE, ret]
  elsif ret = @src.scan(KBD_OPEN_RE)
    @pre << ret
    [:KBD_OPEN, ret]
  elsif ret = @src.scan(KBD_CLOSE_RE)
    @pre << ret
    [:KBD_CLOSE, ret]
  elsif ret = @src.scan(INDEX_OPEN_RE)
    @pre << ret
    [:INDEX_OPEN, ret]
  elsif ret = @src.scan(INDEX_CLOSE_RE)
    @pre << ret
    [:INDEX_CLOSE, ret]
  elsif ret = @src.scan(REF_OPEN_RE)
    @pre << ret
    [:REF_OPEN, ret]
  elsif ret = @src.scan(REF_CLOSE_RE)
    @pre << ret
    [:REF_CLOSE, ret]
  elsif ret = @src.scan(FOOTNOTE_OPEN_RE)
    @pre << ret
    [:FOOTNOTE_OPEN, ret]
  elsif ret = @src.scan(FOOTNOTE_CLOSE_RE)
    @pre << ret
    [:FOOTNOTE_CLOSE, ret]
  elsif ret = @src.scan(VERB_OPEN_RE)
    @pre << ret
    [:VERB_OPEN, ret]
  elsif ret = @src.scan(VERB_CLOSE_RE)
    @pre << ret
    [:VERB_CLOSE, ret]
  elsif ret = @src.scan(BAR_RE)
    @pre << ret
    [:BAR, ret]
  elsif ret = @src.scan(QUOTE_RE)
    @pre << ret
    [:QUOTE, ret]
  elsif ret = @src.scan(SLASH_RE)
    @pre << ret
    [:SLASH, ret]
  elsif ret = @src.scan(BACK_SLASH_RE)
    @pre << ret
    [:BACK_SLASH, ret]
  elsif ret = @src.scan(URL_RE)
    @pre << ret
    [:URL, ret]
  elsif ret = @src.scan(OTHER_RE)
    @pre << ret
    [:OTHER, ret]
  else
    ret = @src.rest
    @pre << ret
    @src.clear
    [:OTHER, ret]
  end
end

def make_reference_from_label(label)
#  Reference.new_from_label_under_document_struct(label, tree.document_struct)
  Reference.new_from_label_without_document_struct(label)
end

def on_error(et, ev, values)
  lines_of_rest = @src.rest.to_a.length
  prev_words = prev_words_on_error(ev)
  at = 4 + prev_words.length
  message = <<-MSG
RD syntax error: line #{@blockp.line_index - lines_of_rest}:
...#{prev_words} #{(ev||'')} #{next_words_on_error()} ...
  MSG
  message << " " * at + "^" * (ev ? ev.length : 0) + "\n"
  raise ParseError, message
end

def prev_words_on_error(ev)
  pre = @pre
  if ev and /#{Regexp.quote(ev)}$/ =~ pre
    pre = $`
  end
  last_line(pre)
end

def last_line(src)
  if n = src.rindex("\n")
    src[(n+1) .. -1]
  else
    src
  end
end
private :last_line

def next_words_on_error
  if n = @src.rest.index("\n")
    @src.rest[0 .. (n-1)]
  else
    @src.rest
  end
end

..end rd/rdinlineparser.ry modeval..ide4f41be34b

##### racc 1.4.1 generates ###

racc_reduce_table = [
 0, 0, :racc_error,
 1, 27, :_reduce_none,
 2, 28, :_reduce_2,
 1, 28, :_reduce_3,
 1, 29, :_reduce_none,
 1, 29, :_reduce_none,
 1, 29, :_reduce_none,
 1, 29, :_reduce_none,
 1, 29, :_reduce_none,
 1, 29, :_reduce_none,
 1, 29, :_reduce_none,
 1, 29, :_reduce_none,
 1, 29, :_reduce_none,
 3, 30, :_reduce_13,
 3, 31, :_reduce_14,
 3, 32, :_reduce_15,
 3, 33, :_reduce_16,
 3, 34, :_reduce_17,
 4, 35, :_reduce_18,
 3, 35, :_reduce_19,
 2, 40, :_reduce_20,
 2, 40, :_reduce_21,
 1, 40, :_reduce_22,
 1, 40, :_reduce_23,
 2, 41, :_reduce_24,
 2, 41, :_reduce_25,
 1, 41, :_reduce_26,
 1, 41, :_reduce_27,
 2, 39, :_reduce_none,
 4, 39, :_reduce_29,
 4, 39, :_reduce_30,
 2, 43, :_reduce_none,
 4, 43, :_reduce_32,
 1, 44, :_reduce_33,
 3, 44, :_reduce_34,
 1, 45, :_reduce_none,
 3, 45, :_reduce_36,
 3, 45, :_reduce_37,
 2, 46, :_reduce_38,
 2, 46, :_reduce_39,
 1, 46, :_reduce_40,
 1, 46, :_reduce_41,
 1, 47, :_reduce_none,
 2, 51, :_reduce_43,
 1, 51, :_reduce_44,
 2, 53, :_reduce_45,
 1, 53, :_reduce_46,
 1, 50, :_reduce_none,
 1, 50, :_reduce_none,
 1, 50, :_reduce_none,
 1, 50, :_reduce_none,
 1, 50, :_reduce_none,
 1, 50, :_reduce_none,
 1, 54, :_reduce_none,
 1, 54, :_reduce_none,
 1, 55, :_reduce_none,
 1, 55, :_reduce_none,
 1, 56, :_reduce_57,
 1, 52, :_reduce_58,
 1, 57, :_reduce_59,
 2, 58, :_reduce_60,
 1, 58, :_reduce_none,
 2, 49, :_reduce_62,
 1, 49, :_reduce_none,
 2, 48, :_reduce_64,
 1, 48, :_reduce_none,
 1, 60, :_reduce_none,
 1, 60, :_reduce_none,
 1, 60, :_reduce_none,
 1, 60, :_reduce_none,
 1, 60, :_reduce_none,
 1, 62, :_reduce_none,
 1, 62, :_reduce_none,
 1, 59, :_reduce_none,
 1, 59, :_reduce_none,
 1, 61, :_reduce_none,
 1, 61, :_reduce_none,
 1, 61, :_reduce_none,
 2, 42, :_reduce_78,
 1, 42, :_reduce_none,
 1, 63, :_reduce_none,
 2, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 1, 63, :_reduce_none,
 3, 36, :_reduce_101,
 3, 37, :_reduce_102,
 1, 65, :_reduce_none,
 1, 65, :_reduce_none,
 1, 65, :_reduce_none,
 1, 65, :_reduce_none,
 1, 65, :_reduce_none,
 1, 65, :_reduce_none,
 2, 66, :_reduce_109,
 1, 66, :_reduce_none,
 1, 38, :_reduce_111,
 1, 67, :_reduce_none,
 2, 67, :_reduce_113,
 2, 67, :_reduce_114,
 2, 67, :_reduce_115,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 1, 68, :_reduce_none,
 2, 64, :_reduce_136,
 1, 64, :_reduce_none ]

racc_reduce_n = 138

racc_shift_n = 179

racc_action_table = [
   130,   134,   137,   139,   141,   143,   144,   123,   125,    84,
   129,   133,   136,   138,   140,   142,   145,   124,   126,   127,
   122,   132,   135,   130,   134,   137,   139,   141,   143,   144,
   123,   125,   164,   129,   133,   136,   138,   140,   142,   145,
   124,   126,   127,   165,   132,   135,   130,   134,   137,   139,
   141,   143,   144,   123,   125,   146,   129,   133,   136,   138,
   140,   142,   145,   124,   126,   127,    93,   132,   135,   130,
   134,   137,   139,   141,   143,   144,   123,   125,    92,   129,
   133,   136,   138,   140,   142,   145,   124,   126,   127,   146,
   132,   135,    39,    42,    45,    90,    49,    52,    54,    32,
    34,   158,    38,    41,    44,    46,    50,    51,    55,    33,
    35,    36,    37,    40,    89,    39,    42,    45,    47,    49,
    52,    54,    32,    34,   171,    38,    41,    44,    46,    50,
    51,    55,    33,    35,    36,    37,    40,    87,     6,     9,
    13,    17,    19,    23,    26,     1,   172,   173,     7,   153,
    14,   174,    20,    94,    27,   106,     3,    86,    59,    10,
     6,     9,    13,    17,    19,    23,    26,     1,   173,    85,
     7,   nil,    14,   nil,    20,   nil,    27,   nil,     3,   nil,
   nil,    10,     6,     9,    13,    17,    19,    23,    26,     1,
   nil,   nil,     7,   nil,    14,   nil,    20,   nil,    27,   nil,
     3,   nil,   nil,    10,     6,     9,    13,    17,    19,    23,
    26,     1,   nil,   nil,     7,   nil,    14,   nil,    20,   nil,
    27,   nil,     3,    71,   nil,    10,    75,    78,    79,    80,
    61,    65,   nil,     7,   nil,    14,   nil,    20,   nil,    27,
   nil,     3,   nil,   nil,    10,     6,     9,    13,    17,    19,
    23,    26,     1,   nil,   nil,     7,   nil,    14,   nil,    20,
   nil,    27,   nil,     3,   nil,   nil,    10,     6,     9,    13,
    17,    19,    23,    26,     1,   nil,   nil,     7,   nil,    14,
   nil,    20,   nil,    27,   nil,     3,   nil,   nil,    10,     6,
     9,    13,    17,    19,    23,    26,     1,   nil,   nil,     7,
   nil,    14,   nil,    20,   nil,    27,   nil,     3,    97,   nil,
    10,    75,    98,    79,    80,    61,    65,   nil,     7,   nil,
    14,   nil,    20,   nil,    27,   nil,     3,   nil,   nil,    10,
     6,     9,    13,    17,    19,    23,    26,     1,   nil,   nil,
     7,   nil,    14,   nil,    20,   nil,    27,   nil,     3,   nil,
   nil,    10,    39,    42,    45,    47,    49,    52,    54,    32,
    34,   nil,    38,    41,    44,    46,    50,    51,    55,    33,
    35,    36,    37,    40,    97,   nil,   nil,    75,    98,    79,
    80,    61,    65,   nil,     7,   nil,    14,   nil,    20,   nil,
    27,   118,     3,   nil,    75,    10,    79,    80,    61,    65,
   nil,     7,   nil,    14,   nil,    20,   nil,    27,   nil,     3,
    97,   nil,    10,    75,    98,    79,    80,    61,    65,   nil,
     7,   nil,    14,   nil,    20,   nil,    27,   nil,     3,    97,
   nil,    10,    75,    98,    79,    80,    61,    65,   nil,     7,
   nil,    14,   nil,    20,   nil,    27,   nil,     3,   nil,   nil,
    10,   112,   113,    75,    98,    79,    80,    61,    65,   nil,
     7,   nil,    14,   nil,    20,   nil,    27,   nil,     3,   nil,
   nil,    10,   112,   113,    75,    98,    79,    80,    61,    65,
   nil,     7,   nil,    14,   nil,    20,   nil,    27,   nil,     3,
   nil,   nil,    10,   112,   113,    75,    98,    79,    80,    61,
    65,   nil,     7,   nil,    14,   nil,    20,   nil,    27,   nil,
     3,    97,   nil,    10,    75,    98,    79,    80,    61,    65,
   167,   nil,   nil,    75,   nil,    79,    80,    61,    65,   175,
   112,   113,    75,    98,    79,    80,    61,    65,   176,   112,
   113,    75,    98,    79,    80,    61,    65,   160,   112,   113,
    75,    98,    79,    80,    61,    65,   148,   nil,   nil,    75,
   151,    79,    80,    61,    65,    97,   nil,   nil,    75,    98,
    79,    80,    61,    65,   178,   112,   113,    75,    98,    79,
    80,    61,    65,   112,   113,    75,    98,    79,    80,    61,
    65,   112,   113,    75,    98,    79,    80,    61,    65,   112,
   113,    75,    98,    79,    80,    61,    65,     6,     9,    13,
    17,    19,    23 ]

racc_action_check = [
    78,    78,    78,    78,    78,    78,    78,    78,    78,    29,
    78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
    76,    78,    78,   170,   170,   170,   170,   170,   170,   170,
   170,   170,   139,   170,   170,   170,   170,   170,   170,   170,
   170,   170,   170,   147,   170,   170,   151,   151,   151,   151,
   151,   151,   151,   151,   151,    81,   151,   151,   151,   151,
   151,   151,   151,   151,   151,   151,    58,   151,   151,   128,
   128,   128,   128,   128,   128,   128,   128,   128,    56,   128,
   128,   128,   128,   128,   128,   128,   128,   128,   128,   152,
   128,   128,    47,    47,    47,    47,    47,    47,    47,    47,
    47,   116,    47,    47,    47,    47,    47,    47,    47,    47,
    47,    47,    47,    47,    47,    43,    43,    43,    43,    43,
    43,    43,    43,    43,   158,    43,    43,    43,    43,    43,
    43,    43,    43,    43,    43,    43,    43,    43,     0,     0,
     0,     0,     0,     0,     0,     0,   160,   160,     0,    83,
     0,   161,     0,    59,     0,    67,     0,    31,    22,     0,
    20,    20,    20,    20,    20,    20,    20,    20,   176,    30,
    20,   nil,    20,   nil,    20,   nil,    20,   nil,    20,   nil,
   nil,    20,     1,     1,     1,     1,     1,     1,     1,     1,
   nil,   nil,     1,   nil,     1,   nil,     1,   nil,     1,   nil,
     1,   nil,   nil,     1,    25,    25,    25,    25,    25,    25,
    25,    25,   nil,   nil,    25,   nil,    25,   nil,    25,   nil,
    25,   nil,    25,    26,   nil,    25,    26,    26,    26,    26,
    26,    26,   nil,    26,   nil,    26,   nil,    26,   nil,    26,
   nil,    26,   nil,   nil,    26,    27,    27,    27,    27,    27,
    27,    27,    27,   nil,   nil,    27,   nil,    27,   nil,    27,
   nil,    27,   nil,    27,   nil,   nil,    27,     3,     3,     3,
     3,     3,     3,     3,     3,   nil,   nil,     3,   nil,     3,
   nil,     3,   nil,     3,   nil,     3,   nil,   nil,     3,     7,
     7,     7,     7,     7,     7,     7,     7,   nil,   nil,     7,
   nil,     7,   nil,     7,   nil,     7,   nil,     7,   107,   nil,
     7,   107,   107,   107,   107,   107,   107,   nil,   107,   nil,
   107,   nil,   107,   nil,   107,   nil,   107,   nil,   nil,   107,
    14,    14,    14,    14,    14,    14,    14,    14,   nil,   nil,
    14,   nil,    14,   nil,    14,   nil,    14,   nil,    14,   nil,
   nil,    14,    10,    10,    10,    10,    10,    10,    10,    10,
    10,   nil,    10,    10,    10,    10,    10,    10,    10,    10,
    10,    10,    10,    10,    64,   nil,   nil,    64,    64,    64,
    64,    64,    64,   nil,    64,   nil,    64,   nil,    64,   nil,
    64,    72,    64,   nil,    72,    64,    72,    72,    72,    72,
   nil,    72,   nil,    72,   nil,    72,   nil,    72,   nil,    72,
    69,   nil,    72,    69,    69,    69,    69,    69,    69,   nil,
    69,   nil,    69,   nil,    69,   nil,    69,   nil,    69,   102,
   nil,    69,   102,   102,   102,   102,   102,   102,   nil,   102,
   nil,   102,   nil,   102,   nil,   102,   nil,   102,   nil,   nil,
   102,   111,   111,   111,   111,   111,   111,   111,   111,   nil,
   111,   nil,   111,   nil,   111,   nil,   111,   nil,   111,   nil,
   nil,   111,   118,   118,   118,   118,   118,   118,   118,   118,
   nil,   118,   nil,   118,   nil,   118,   nil,   118,   nil,   118,
   nil,   nil,   118,    71,    71,    71,    71,    71,    71,    71,
    71,   nil,    71,   nil,    71,   nil,    71,   nil,    71,   nil,
    71,   105,   nil,    71,   105,   105,   105,   105,   105,   105,
   149,   nil,   nil,   149,   nil,   149,   149,   149,   149,   162,
   162,   162,   162,   162,   162,   162,   162,   162,   166,   166,
   166,   166,   166,   166,   166,   166,   166,   117,   117,   117,
   117,   117,   117,   117,   117,   117,    82,   nil,   nil,    82,
    82,    82,    82,    82,    82,    62,   nil,   nil,    62,    62,
    62,    62,    62,    62,   177,   177,   177,   177,   177,   177,
   177,   177,   177,   148,   148,   148,   148,   148,   148,   148,
   148,   167,   167,   167,   167,   167,   167,   167,   167,   157,
   157,   157,   157,   157,   157,   157,   157,    16,    16,    16,
    16,    16,    16 ]

racc_action_pointer = [
   135,   179,   nil,   264,   nil,   nil,   nil,   286,   nil,   nil,
   349,   nil,   nil,   nil,   327,   nil,   604,   nil,   nil,   nil,
   157,   nil,   158,   nil,   nil,   201,   220,   242,   nil,    -2,
   147,   143,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   nil,   112,   nil,   nil,   nil,    89,   nil,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,    62,   nil,    48,   153,
   nil,   nil,   562,   nil,   371,   nil,   nil,   132,   nil,   407,
   nil,   489,   388,   nil,   nil,   nil,    16,   nil,    -3,   nil,
   nil,    50,   553,   129,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   426,   nil,   nil,   508,   nil,   305,   nil,   nil,
   nil,   447,   nil,   nil,   nil,   nil,    98,   544,   468,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,    66,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,    26,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,    20,   579,   517,
   nil,    43,    84,   nil,   nil,   nil,   nil,   595,   120,   nil,
   142,   148,   526,   nil,   nil,   nil,   535,   587,   nil,   nil,
    20,   nil,   nil,   nil,   nil,   nil,   163,   571,   nil ]

racc_action_default = [
  -138,  -138,    -4,  -138,    -5,    -6,  -104,  -138,    -7,  -105,
  -138,    -8,  -110,  -106,  -138,    -9,  -111,  -107,   -10,  -108,
  -138,   -11,  -138,  -103,   -12,    -1,  -138,  -138,    -3,  -138,
  -138,  -138,  -132,  -127,  -133,  -128,  -129,  -131,  -120,  -117,
  -134,  -121,  -118,  -138,  -122,  -119,  -123,  -138,  -137,  -135,
  -124,  -125,  -116,  -112,  -130,  -126,  -138,  -109,  -138,  -138,
    -2,   -69,   -63,   -47,   -41,   -70,   -48,  -138,   -49,   -40,
   -50,  -138,   -27,   -51,   -26,   -67,   -35,   -52,  -138,   -66,
   -68,   -58,  -138,  -138,  -101,   -17,   -13,  -102,  -136,  -114,
  -115,  -113,   -14,   -15,   179,   -71,   -73,   -74,   -72,   -62,
   -61,   -53,   -38,   -44,   -54,   -57,   -19,   -39,   -55,   -65,
   -75,   -42,   -76,   -77,   -46,   -56,  -138,   -59,  -138,   -25,
   -35,   -58,   -28,   -97,   -93,   -98,   -94,   -95,   -24,   -86,
   -85,   -79,   -99,   -87,   -84,  -100,   -88,   -83,   -89,  -138,
   -90,   -82,   -91,   -80,   -96,   -92,   -31,  -138,  -138,   -23,
   -22,  -138,   -33,   -16,   -60,   -43,   -45,   -59,   -36,   -64,
   -37,  -138,   -59,   -78,   -81,   -18,  -138,  -138,   -21,   -33,
   -20,   -29,   -30,   -32,   -36,   -37,   -34,  -138,   -34 ]

racc_goto_table = [
    81,    62,   117,   128,   150,    64,    76,    72,   116,   154,
    48,   102,   163,   159,    74,   154,   107,   155,    22,    29,
   147,    30,   155,    99,    96,    31,    96,   156,    82,    67,
    43,    96,    56,    57,    60,    91,   nil,   nil,    58,   nil,
   nil,   nil,   157,    88,   nil,    83,   121,    62,   nil,   162,
   108,    64,   120,   159,   163,   161,   152,    62,   159,   nil,
   119,    96,   159,   149,    96,   nil,   nil,    96,   nil,    96,
   nil,   168,   nil,   159,     8,     8,   170,     8,   nil,   166,
   nil,     8,     2,     2,   nil,     2,   nil,   nil,     8,     2,
   108,   nil,   nil,   nil,     8,   nil,     2,   108,   177,     8,
   nil,     8,     2,   nil,   nil,     4,     4,     2,     4,     2,
   nil,   nil,     4,    21,    21,   nil,    21,   nil,   nil,     4,
    21,   nil,   nil,   169,    62,     4,   nil,    21,     5,     5,
     4,     5,     4,    21,   nil,     5,    11,    11,    21,    11,
    21,   nil,     5,    11,   nil,   nil,   nil,   nil,     5,   nil,
    11,   nil,   nil,     5,   nil,     5,    11,   nil,   nil,   nil,
   nil,    11,   nil,    11 ]

racc_goto_check = [
    23,    34,    22,    16,    18,    24,    20,    17,    21,    33,
    41,    25,    37,    35,    19,    33,    25,    28,     1,     1,
    14,     1,    28,    32,    36,     1,    36,    29,    13,    15,
    38,    36,     1,    39,     3,    42,   nil,   nil,     1,   nil,
   nil,   nil,    22,    41,   nil,     1,    23,    34,   nil,    22,
    24,    24,    20,    35,    37,    21,    23,    34,    35,   nil,
    19,    36,    35,    17,    36,   nil,   nil,    36,   nil,    36,
   nil,    18,   nil,    35,     7,     7,    16,     7,   nil,    22,
   nil,     7,     4,     4,   nil,     4,   nil,   nil,     7,     4,
    24,   nil,   nil,   nil,     7,   nil,     4,    24,    22,     7,
   nil,     7,     4,   nil,   nil,     5,     5,     4,     5,     4,
   nil,   nil,     5,    11,    11,   nil,    11,   nil,   nil,     5,
    11,   nil,   nil,    23,    34,     5,   nil,    11,     6,     6,
     5,     6,     5,    11,   nil,     6,     8,     8,    11,     8,
    11,   nil,     6,     8,   nil,   nil,   nil,   nil,     6,   nil,
     8,   nil,   nil,     6,   nil,     6,     8,   nil,   nil,   nil,
   nil,     8,   nil,     8 ]

racc_goto_pointer = [
   nil,    18,   nil,     9,    82,   105,   128,    74,   136,   nil,
   nil,   113,   nil,     2,   -62,     3,   -75,   -19,   -78,   -12,
   -20,   -63,   -69,   -26,   -21,   -53,   nil,   nil,   -85,   -84,
   nil,   nil,   -39,   -90,   -25,  -104,   -38,  -116,    20,    17,
   nil,     0,   -12 ]

racc_goto_default = [
   nil,   nil,    25,    28,    63,    66,    68,    70,    73,    15,
    18,    77,    24,   nil,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   nil,   nil,   101,   nil,    69,   111,   103,   114,
   104,   115,   105,   100,    95,   109,   110,   131,   nil,    12,
    16,   nil,    53 ]

racc_token_table = {
 false => 0,
 Object.new => 1,
 :EX_LOW => 2,
 :QUOTE => 3,
 :BAR => 4,
 :SLASH => 5,
 :BACK_SLASH => 6,
 :URL => 7,
 :OTHER => 8,
 :REF_OPEN => 9,
 :FOOTNOTE_OPEN => 10,
 :FOOTNOTE_CLOSE => 11,
 :EX_HIGH => 12,
 :EM_OPEN => 13,
 :EM_CLOSE => 14,
 :CODE_OPEN => 15,
 :CODE_CLOSE => 16,
 :VAR_OPEN => 17,
 :VAR_CLOSE => 18,
 :KBD_OPEN => 19,
 :KBD_CLOSE => 20,
 :INDEX_OPEN => 21,
 :INDEX_CLOSE => 22,
 :REF_CLOSE => 23,
 :VERB_OPEN => 24,
 :VERB_CLOSE => 25 }

racc_use_result_var = true

racc_nt_base = 26

Racc_arg = [
 racc_action_table,
 racc_action_check,
 racc_action_default,
 racc_action_pointer,
 racc_goto_table,
 racc_goto_check,
 racc_goto_default,
 racc_goto_pointer,
 racc_nt_base,
 racc_reduce_table,
 racc_token_table,
 racc_shift_n,
 racc_reduce_n,
 racc_use_result_var ]

Racc_token_to_s_table = [
'$end',
'error',
'EX_LOW',
'QUOTE',
'BAR',
'SLASH',
'BACK_SLASH',
'URL',
'OTHER',
'REF_OPEN',
'FOOTNOTE_OPEN',
'FOOTNOTE_CLOSE',
'EX_HIGH',
'EM_OPEN',
'EM_CLOSE',
'CODE_OPEN',
'CODE_CLOSE',
'VAR_OPEN',
'VAR_CLOSE',
'KBD_OPEN',
'KBD_CLOSE',
'INDEX_OPEN',
'INDEX_CLOSE',
'REF_CLOSE',
'VERB_OPEN',
'VERB_CLOSE',
'$start',
'content',
'elements',
'element',
'emphasis',
'code',
'var',
'keyboard',
'index',
'reference',
'footnote',
'verb',
'normal_str_ele',
'substitute',
'ref_label',
'ref_label2',
'ref_url_strings',
'filename',
'element_label',
'element_label2',
'ref_subst_content',
'ref_subst_content_q',
'ref_subst_strings_q',
'ref_subst_strings_first',
'ref_subst_ele2',
'ref_subst_eles',
'ref_subst_str_ele_first',
'ref_subst_eles_q',
'ref_subst_ele',
'ref_subst_ele_q',
'ref_subst_str_ele',
'ref_subst_str_ele_q',
'ref_subst_strings',
'ref_subst_string3',
'ref_subst_string',
'ref_subst_string_q',
'ref_subst_string2',
'ref_url_string',
'verb_strings',
'normal_string',
'normal_strings',
'verb_string',
'verb_normal_string']

Racc_debug_parser = false

##### racc system variables end #####

 # reduce 0 omitted

 # reduce 1 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 23
  def _reduce_2( val, _values, result )
 result.push(val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 24
  def _reduce_3( val, _values, result )
 result = val
   result
  end
.,.,

 # reduce 4 omitted

 # reduce 5 omitted

 # reduce 6 omitted

 # reduce 7 omitted

 # reduce 8 omitted

 # reduce 9 omitted

 # reduce 10 omitted

 # reduce 11 omitted

 # reduce 12 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 38
  def _reduce_13( val, _values, result )
		result = Emphasis.new
                add_children_to_element(result, *val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 43
  def _reduce_14( val, _values, result )
		result = Code.new
                add_children_to_element(result, *val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 48
  def _reduce_15( val, _values, result )
		result = Var.new
                add_children_to_element(result, *val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 53
  def _reduce_16( val, _values, result )
		result = Keyboard.new
                add_children_to_element(result, *val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 58
  def _reduce_17( val, _values, result )
		result = Index.new
                add_children_to_element(result, *val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 67
  def _reduce_18( val, _values, result )
 result = Reference.new(val[2])
                          add_children_to_element(result, *val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 72
  def _reduce_19( val, _values, result )
                          result = make_reference_from_label(val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 76
  def _reduce_20( val, _values, result )
 result = Reference::URL.new(val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 78
  def _reduce_21( val, _values, result )
 result = Reference::TemporaryLabel.new(val[1],
			           val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 81
  def _reduce_22( val, _values, result )
 result = Reference::TemporaryLabel.new(val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 82
  def _reduce_23( val, _values, result )
 result = Reference::TemporaryLabel.new([], val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 84
  def _reduce_24( val, _values, result )
 result = Reference::URL.new(val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 86
  def _reduce_25( val, _values, result )
 result = Reference::TemporaryLabel.new(val[1],
				   val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 89
  def _reduce_26( val, _values, result )
 result = Reference::TemporaryLabel.new(val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 90
  def _reduce_27( val, _values, result )
 result = Reference::TemporaryLabel.new([],
				     val[0])
   result
  end
.,.,

 # reduce 28 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 95
  def _reduce_29( val, _values, result )
 result = val[1]
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 97
  def _reduce_30( val, _values, result )
 result = [StringElement.new(val[1])]
   result
  end
.,.,

 # reduce 31 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 102
  def _reduce_32( val, _values, result )
 result = val[1]
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 107
  def _reduce_33( val, _values, result )
 result = [StringElement.new(val[0])]
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 109
  def _reduce_34( val, _values, result )
 result = [StringElement.new(val[1])]
   result
  end
.,.,

 # reduce 35 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 115
  def _reduce_36( val, _values, result )
 result = val[1]
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 117
  def _reduce_37( val, _values, result )
 result = [StringElement.new(val[1])]
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 121
  def _reduce_38( val, _values, result )
 result = val[1].unshift(val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 123
  def _reduce_39( val, _values, result )
 result = val[1].unshift(val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 125
  def _reduce_40( val, _values, result )
 result = val
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 126
  def _reduce_41( val, _values, result )
 result = val
   result
  end
.,.,

 # reduce 42 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 131
  def _reduce_43( val, _values, result )
 result.push(val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 132
  def _reduce_44( val, _values, result )
 result = val
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 135
  def _reduce_45( val, _values, result )
 result.push(val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 136
  def _reduce_46( val, _values, result )
 result = val
   result
  end
.,.,

 # reduce 47 omitted

 # reduce 48 omitted

 # reduce 49 omitted

 # reduce 50 omitted

 # reduce 51 omitted

 # reduce 52 omitted

 # reduce 53 omitted

 # reduce 54 omitted

 # reduce 55 omitted

 # reduce 56 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 153
  def _reduce_57( val, _values, result )
 result = StringElement.new(val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 156
  def _reduce_58( val, _values, result )
 result = StringElement.new(val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 159
  def _reduce_59( val, _values, result )
 result = StringElement.new(val[0])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 163
  def _reduce_60( val, _values, result )
 result << val[1]
   result
  end
.,.,

 # reduce 61 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 169
  def _reduce_62( val, _values, result )
 result << val[1]
   result
  end
.,.,

 # reduce 63 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 173
  def _reduce_64( val, _values, result )
 result << val[1]
   result
  end
.,.,

 # reduce 65 omitted

 # reduce 66 omitted

 # reduce 67 omitted

 # reduce 68 omitted

 # reduce 69 omitted

 # reduce 70 omitted

 # reduce 71 omitted

 # reduce 72 omitted

 # reduce 73 omitted

 # reduce 74 omitted

 # reduce 75 omitted

 # reduce 76 omitted

 # reduce 77 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 196
  def _reduce_78( val, _values, result )
 result << val[1]
   result
  end
.,.,

 # reduce 79 omitted

 # reduce 80 omitted

 # reduce 81 omitted

 # reduce 82 omitted

 # reduce 83 omitted

 # reduce 84 omitted

 # reduce 85 omitted

 # reduce 86 omitted

 # reduce 87 omitted

 # reduce 88 omitted

 # reduce 89 omitted

 # reduce 90 omitted

 # reduce 91 omitted

 # reduce 92 omitted

 # reduce 93 omitted

 # reduce 94 omitted

 # reduce 95 omitted

 # reduce 96 omitted

 # reduce 97 omitted

 # reduce 98 omitted

 # reduce 99 omitted

 # reduce 100 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 227
  def _reduce_101( val, _values, result )
		result = Footnote.new
                add_children_to_element(result, *val[1])
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 232
  def _reduce_102( val, _values, result )
				result = Verb.new(val[1])
   result
  end
.,.,

 # reduce 103 omitted

 # reduce 104 omitted

 # reduce 105 omitted

 # reduce 106 omitted

 # reduce 107 omitted

 # reduce 108 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 246
  def _reduce_109( val, _values, result )
 result << val[1]
   result
  end
.,.,

 # reduce 110 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 251
  def _reduce_111( val, _values, result )
 result = StringElement.new(val[0])
   result
  end
.,.,

 # reduce 112 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 256
  def _reduce_113( val, _values, result )
 result = val[1]
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 257
  def _reduce_114( val, _values, result )
 result = val[1]
   result
  end
.,.,

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 258
  def _reduce_115( val, _values, result )
 result = val[1]
   result
  end
.,.,

 # reduce 116 omitted

 # reduce 117 omitted

 # reduce 118 omitted

 # reduce 119 omitted

 # reduce 120 omitted

 # reduce 121 omitted

 # reduce 122 omitted

 # reduce 123 omitted

 # reduce 124 omitted

 # reduce 125 omitted

 # reduce 126 omitted

 # reduce 127 omitted

 # reduce 128 omitted

 # reduce 129 omitted

 # reduce 130 omitted

 # reduce 131 omitted

 # reduce 132 omitted

 # reduce 133 omitted

 # reduce 134 omitted

 # reduce 135 omitted

module_eval <<'.,.,', 'rd/rdinlineparser.ry', 283
  def _reduce_136( val, _values, result )
 result << val[1]
   result
  end
.,.,

 # reduce 137 omitted

 def _reduce_none( val, _values, result )
  result
 end

end   # class RDInlineParser

end # end of module RD

